(function() {
'use strict';
let definitions = {
  defaults: {
    version: "undefined",
    applyCasing: function defaultApplyCasing(casing, text) {
    switch (casing) {
        case 'lower':
            return text.toLowerCase();
        case 'upper':
            return text.toUpperCase();
        case 'initial':
            let headCode = text.charCodeAt(0);
            // The length of the first code unit, as measured in code points.
            let headUnitLength = 1;
            // Is the first character a high surrogate, indicating possible use of UTF-16 
            // surrogate pairs?  Also, is the string long enough for there to BE a pair?
            if (text.length > 1 && headCode >= 0xD800 && headCode <= 0xDBFF) {
                // It's possible, so now we check for low surrogates.
                let lowSurrogateCode = text.charCodeAt(1);
                if (lowSurrogateCode >= 0xDC00 && lowSurrogateCode <= 0xDFFF) {
                    // We have a surrogate pair; this pair is the 'first' character.
                    headUnitLength++;
                }
            }
            // Capitalizes the first code unit of the string, leaving the rest intact.
            return text.substring(0, headUnitLength).toUpperCase() // head - uppercased
                .concat(text.substring(headUnitLength)); // tail - lowercased
    }
}
  },  model: {
    searchTermToKey: function defaultCasedSearchTermToKey(wordform, applyCasing) {
    // While this is a bit WET, as the basic `defaultSearchTermToKey` exists and performs some of
    // the same functions, repetition is the easiest way to allow the function to be safely compiled 
    // with ease by use of `.toString()`.
    return Array.from(wordform
        .normalize('NFKD')
        // Remove any combining diacritics (if input is in NFKD)
        .replace(/[\u0300-\u036F]/g, '')) // end of `Array.from`
        .map(c => applyCasing('lower', c))
        .join('');
}
  },
  applyCasing: function(caseToApply, text) {
        return definitions.defaults.applyCasing(caseToApply, text);
      },
  searchTermToKey: function(text) {
      return definitions.model.searchTermToKey(text, definitions.applyCasing);
    }
};
LMLayerWorker.loadModel(new models.TrieModel({"totalWeight":28,"root":{"type":"internal","weight":1,"values":["ប","ម"],"children":{"ប":{"type":"internal","weight":1,"values":["ង","ម","ន"],"children":{"ង":{"type":"internal","weight":1,"values":["្"],"children":{"្":{"type":"internal","weight":1,"values":["រ","ក","គ","ខ"],"children":{"រ":{"type":"leaf","weight":1,"entries":[{"key":"បង្រៀន","weight":1,"content":"បង្រៀន"}]},"ក":{"type":"internal","weight":1,"values":["ើ","ា","ៃ","ោ","្"],"children":{"ើ":{"type":"internal","weight":1,"values":["ត","យ"],"children":{"ត":{"type":"leaf","weight":1,"entries":[{"key":"បង្កើត","weight":1,"content":"បង្កើត"}]},"យ":{"type":"leaf","weight":1,"entries":[{"key":"បង្កើយ","weight":1,"content":"បង្កើយ"}]}}},"ា":{"type":"leaf","weight":1,"entries":[{"key":"បង្កាត់","weight":1,"content":"បង្កាត់"}]},"ៃ":{"type":"leaf","weight":1,"entries":[{"key":"បង្កៃ","weight":1,"content":"បង្កៃ"}]},"ោ":{"type":"leaf","weight":1,"entries":[{"key":"បង្កោង","weight":1,"content":"បង្កោង"}]},"្":{"type":"internal","weight":1,"values":["រ"],"children":{"រ":{"type":"internal","weight":1,"values":["ា","ៀ"],"children":{"ា":{"type":"leaf","weight":1,"entries":[{"key":"បង្ក្រាប","weight":1,"content":"បង្ក្រាប"}]},"ៀ":{"type":"leaf","weight":1,"entries":[{"key":"បង្ក្រៀក","weight":1,"content":"បង្ក្រៀក"}]}}}}}}},"គ":{"type":"internal","weight":1,"values":["្","ី"],"children":{"្":{"type":"leaf","weight":1,"entries":[{"key":"បង្គ្រប់","weight":1,"content":"បង្គ្រប់"}]},"ី":{"type":"leaf","weight":1,"entries":[{"key":"បង្គី","weight":1,"content":"បង្គី"}]}}},"ខ":{"type":"internal","weight":1,"values":["ា","ូ","ិ","ើ","ក","ុ","ំ","ន"],"children":{"ា":{"type":"internal","weight":1,"values":["ក","ំ","ត","ន"],"children":{"ក":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខាក","weight":1,"content":"បង្ខាក"}]},"ំ":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខាំង","weight":1,"content":"បង្ខាំង"},{"key":"បង្ខាំ","weight":1,"content":"បង្ខាំ"}]},"ត":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខាត","weight":1,"content":"បង្ខាត"}]},"ន":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខាន","weight":1,"content":"បង្ខាន"}]}}},"ូ":{"type":"internal","weight":1,"values":["ច","ង"],"children":{"ច":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខូច","weight":1,"content":"បង្ខូច"}]},"ង":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខូង","weight":1,"content":"បង្ខូង"}]}}},"ិ":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខិត","weight":1,"content":"បង្ខិត"}]},"ើ":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខើច","weight":1,"content":"បង្ខើច"}]},"ក":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខក","weight":1,"content":"បង្ខក"}]},"ុ":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខុស","weight":1,"content":"បង្ខុស"}]},"ំ":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខំ","weight":1,"content":"បង្ខំ"}]},"ន":{"type":"leaf","weight":1,"entries":[{"key":"បង្ខន","weight":1,"content":"បង្ខន"}]}}}}}}},"ម":{"type":"leaf","weight":1,"entries":[{"key":"បម្រើ","weight":1,"content":"បម្រើ"}]},"ន":{"type":"internal","weight":1,"values":["្"],"children":{"្":{"type":"internal","weight":1,"values":["ស"],"children":{"ស":{"type":"internal","weight":1,"values":["ំ","៊","ា"],"children":{"ំ":{"type":"leaf","weight":1,"entries":[{"key":"បន្សំ","weight":1,"content":"បន្សំ"}]},"៊":{"type":"leaf","weight":1,"entries":[{"key":"បន្ស៊ី","weight":1,"content":"បន្ស៊ី"}]},"ា":{"type":"leaf","weight":1,"entries":[{"key":"បន្សាយ","weight":1,"content":"បន្សាយ"}]}}}}}}}}},"ម":{"type":"leaf","weight":1,"entries":[{"key":"ម្រាយ","weight":1,"content":"ម្រាយ"}]}}}}, {
  wordBreaker: function (str) {
        return str.split(/\s/).map(function (token) {
            return {
                left: str.indexOf(token),
                start: str.indexOf(token),
                right: str.indexOf(token) + token.length,
                end: str.indexOf(token) + token.length,
                text: token
            };
        });
    },
  searchTermToKey: definitions.searchTermToKey,
}));
})();